@@ -1,15 +1,17 @@
 package Tk::JPEG;
 require DynaLoader;
-use Tk 800.005;
+use Tk 800.015;
 require Tk::Image;
 require Tk::Photo;
+require DynaLoader;
 
-use vars qw($VERSION);
-$VERSION = '2.012'; # $Id: //depot/tkJPEG/JPEG.pm#11$
+use vars qw($VERSION $XS_VERSION);
+$VERSION = '2.013'; # $Id: //depot/tkJPEG/JPEG.pm#13$
 
 @ISA = qw(DynaLoader);
 
-bootstrap Tk::JPEG $Tk::VERSION;
+$XS_VERSION = $Tk::VERSION;
+bootstrap Tk::JPEG;
 
 1;
 
@@ -29,7 +31,7 @@ Tk::JPEG - JPEG loader for Tk::Photo
 
 =head1 DESCRIPTION
 
-This is an extension for Tk400.* or Tk402.* which supplies
+This is an extension for Tk800.015 and later which supplies
 JPEG format loader for Photo image type.
 
 JPEG access is via release 5 of the The Independent JPEG Group's (IJG)
